@@ -1,6 +1,6 @@
 package Getopt::EX::Hashed;
 
-our $VERSION = '0.9914';
+our $VERSION = '0.9915';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Getopt::EX::Hashed - Hash store object automation
 
 =head1 VERSION
 
-Version 0.9914
+Version 0.9915
 
 =head1 SYNOPSIS
 
@@ -131,21 +131,18 @@ sub new {
     my $ctx = $class ne __PACKAGE__ ? $class : caller;
     my $M = __Member__($ctx);
     my $C = __Config__($ctx);
-    my $member = $obj->{__Hash__} = {
-	map {
-	    my($key, %param) = @$_;
-	    $key => \%param;
-	} @$M
-    };
-    my $order = $obj->{__Order__} = [ map $_->[0], @$M ];
-    for my $key (@$order) {
-	my $m = $member->{$key};
-	$obj->{$key} = $m->{default};
-	if (my $is = $m->{is}) {
+    my $order = $obj->{__Order__} = [];
+    my $member = $obj->{__Hash__} = {};
+    for my $M (@$M) {
+	my($name, %param) = @$M;
+	if (my $is = $param{is}) {
 	    no strict 'refs';
-	    my $access = $C->{ACCESSOR_PREFIX} . $key;
-	    *{"$class\::$access"} = _accessor($is, $key);
+	    my $access = $C->{ACCESSOR_PREFIX} . $name;
+	    *{"$class\::$access"} = _accessor($is, $name);
 	}
+	$obj->{$name} = $param{default};
+	push @$order, $name;
+	$member->{$name} = \%param;
     }
     lock_keys %$obj if $C->{LOCK_KEYS};
     __PACKAGE__->reset if $C->{RESET_AFTER_NEW};
@@ -206,7 +203,10 @@ sub _optspec {
 		$action ||= \&_generic_setter;
 		sub {
 		    local $_ = $obj;
-		    &$is_valid or die "@_: invalid option/value.\n";
+		    &$is_valid or do {
+			local $" = ' -> ';
+			die "@_: invalid option/value.\n";
+		    };
 		    &$action;
 		};
 	    }
@@ -225,14 +225,24 @@ sub _optspec {
     } @spec;
 }
 
+my %tester = (
+    min  => sub { $_[-1] >= $_->{min} },
+    max  => sub { $_[-1] <= $_->{max} },
+    re   => sub { $_[-1] =~ $_->{re} },
+    must => sub { &{$_->{must}} },
+    );
+
+sub _tester {
+    my $m = shift;
+    map { $tester{$_} } grep { defined $m->{$_} } keys %tester;
+}
+
 sub _validator {
     my $m = shift;
-    grep { defined } @{$m}{qw(min max re must)} or return undef;
+    my @test = _tester($m) or return undef;
     sub {
-	defined $m->{min}  and $_[-1] <  $m->{min} and return 0;
-	defined $m->{max}  and $_[-1] >  $m->{max} and return 0;
-	defined $m->{re}   and $_[-1] !~ $m->{re}  and return 0;
-	defined $m->{must} and not &{$m->{must}}   and return 0;
+	local $_ = $m;
+	for my $test (@test) { &$test or return 0 }
 	return 1;
     }
 }
@@ -326,10 +336,15 @@ Following parameters are available.
 
 =over 7
 
-=item B<is> => I<ro> | I<rw>
+=item B<is> => C<ro> | C<rw>
 
-If an C<is> parameter is given, accessor method for the member,
-read-only for I<ro> and read-write for I<rw>, is generated.
+To produce accessor method, C<is> parameter is necessary.  Set the
+value C<ro> for read-only, C<rw> for read-write.
+
+If you want to make accessor for all following members, use
+C<configure> and set C<DEFAULT> parameter.
+
+    Getopt::EX::Hashed->configure( DEFAULT => is => 'rw' );
 
 =item B<spec> => I<string>
 
@@ -374,7 +389,7 @@ as C<undef>.
 =item B<action> => I<coderef>
 
 Parameter C<action> takes code reference which is called to process
-the option.  When called, hash object is passed through C<$_>.
+the option.  When called, hash object is passed as C<$_>.
 
     has [ qw(left right both) ] => spec => '=i';
     has "+both" => action => sub {
@@ -431,6 +446,16 @@ Set the required regular expression pattern for the argument.
 
 Class method to get initialized hash object.
 
+=item B<optspec>
+
+Return option specification list which can be given to C<GetOptions>
+function.
+
+    GetOptions($obj->optspec)
+
+C<GetOptions> has a capability of storing values in a hash, by giving
+the hash reference as a first argument, but it is not necessary.
+
 =item B<getopt>
 
 Call C<GetOptions> function defined in caller's context with
@@ -442,16 +467,10 @@ is just a shortcut for:
 
     GetOptions($obj->optspec)
 
-=item B<optspec>
-
-Return option specification list which can be given to C<GetOptions>
-function.  GetOptions has a capability of storing values in a hash, by
-giving the hash reference as a first argument, but it is not expected.
-
 =item B<use_keys>
 
 Because hash keys are protected by C<Hash::Util::lock_keys>, accessing
-non-existing member causes an error.  Use this function to declare new
+non-existent member causes an error.  Use this function to declare new
 member key before use.
 
     $obj->use_keys( qw(foo bar) );
@@ -461,6 +480,9 @@ If you want to access arbitrary keys, unlock the object.
     use Hash::Util 'unlock_keys';
     unlock_keys %{$obj};
 
+You can change this behavior by C<configure> with C<LOCK_KEYS>
+parameter.
+
 =item B<reset>
 
 Reset the class to original state.  Because the hash object keeps all
@@ -475,6 +497,13 @@ This is almost equivalent to the next code:
     my $obj = Getopt::EX::Hashed->new;
     Getopt::EX::Hashed->reset;
 
+=begin comment
+
+You can change this behavior by C<configure> with C<RESET_AFTER_NEW>
+parameter.
+
+=end comment
+
 =item B<configure> B<label> => I<value>, ...
 
 There are following configuration parameters.
@@ -483,7 +512,7 @@ There are following configuration parameters.
 
 =item B<LOCK_KEYS> (default: 1)
 
-Lock hash keys.  This avoids accidental access to non-existing hash
+Lock hash keys.  This avoids accidental access to non-existent hash
 entry.
 
 =item B<REPLACE_UNDERSCORE> (default: 1)
